@@ -293,9 +293,9 @@ class Client:
     ) -> dict:
         api = "https://pan.baidu.com/api/gettemplatevariable"
         if isinstance(payload, str):
-            payload = {"fields": dumps([payload])}
+            payload = {"fields": dumps([payload], separators=(",", ":"))}
         elif isinstance(payload, (tuple, list)):
-            payload = {"fields": dumps(payload)}
+            payload = {"fields": dumps(payload, separators=(",", ":"))}
         return self.request(api, params=payload)
 
     def listdir(
@@ -357,12 +357,12 @@ class Client:
             **params, 
         }
         if isinstance(data, str):
-            data = {"filelist": dumps([data])}
+            data = {"filelist": dumps([data], separators=(",", ":"))}
         elif isinstance(data, dict):
             if "filelist" not in data:
-                data = {"filelist": dumps([data])}
+                data = {"filelist": dumps([data], separators=(",", ":"))}
         elif isinstance(data, (list, tuple)):
-            data = {"filelist": dumps(data)}
+            data = {"filelist": dumps(data, separators=(",", ":"))}
         return self.request(api, "POST", params=params, data=data)
 
     def copy(
@@ -406,6 +406,7 @@ class Client:
     def transfer(
         self, 
         /, 
+        url, 
         params: dict, 
         data: int | str | list | tuple | dict, 
     ) -> dict:
@@ -422,7 +423,9 @@ class Client:
             data = {"fsidlist": "[%s]" % data, "path": "/"}
         elif isinstance(data, (list, tuple)):
             data = {"fsidlist": "[%s]" % ", ".join(map(str, data)), "path": "/"}
-        return self.request(api, "POST", params=params, data=data)
+        elif isinstance(data["fsidlist"], (list, tuple)):
+            data["fsidlist"] = "[%s]" % ", ".join(map(str, data))
+        return self.request(api, "POST", params=params, data=data, headers={"Referer": url})
 
 
 class ShareList:
